jactorch.transforms.image.transforms
====================================

.. automodule:: jactorch.transforms.image.transforms

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      Pad
      PadMultipleOf
   
   

   
   
   

   
   
   








.. rubric:: Class Pad
.. autoclass:: Pad
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class PadMultipleOf
.. autoclass:: PadMultipleOf
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







